pub struct MessageReader { /* private fields */ }Expand description
Incremental reader for PostgreSQL backend messages.
Implementations
Sourceimpl MessageReader
impl MessageReader
Sourcepub fn with_max_size(max_message_size: usize) -> Self
pub fn with_max_size(max_message_size: usize) -> Self
Create a new reader with a custom max message size.
Sourcepub fn buffered_len(&self) -> usize
pub fn buffered_len(&self) -> usize
Number of bytes currently buffered.
Sourcepub fn feed(
&mut self,
data: &[u8],
) -> Result<Vec<BackendMessage>, ProtocolError>
pub fn feed( &mut self, data: &[u8], ) -> Result<Vec<BackendMessage>, ProtocolError>
Feed bytes into the reader and return any complete messages.
Sourcepub fn next_message(&mut self) -> Result<Option<BackendMessage>, ProtocolError>
pub fn next_message(&mut self) -> Result<Option<BackendMessage>, ProtocolError>
Attempt to parse the next message from the internal buffer.
Sourcepub fn parse_message(frame: &[u8]) -> Result<BackendMessage, ProtocolError>
pub fn parse_message(frame: &[u8]) -> Result<BackendMessage, ProtocolError>
Parse a single full message frame (type + length + payload).